package Bundle::SQL;

use strict;
use warnings;


our $VERSION = '0.04';



1;
__END__


=head1 NAME

Bundle::SQL - installs SQL modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::SQL'

=head1 CONTENTS

DBI

DBI::Dumper

Class::Accessor::Grouped

MRO::Compat

Ima::DBI

Class::DBI::SQLite

HTTP::Daemon

Cwd

Template

Class::Accessor

DBD::SQLite

URI

Text::Sentence

Test::More

Test::MockObject

SPOPS

Scalar::Util

Pod::POM

Mail::RFC822::Address

MIME::Lite

LWP::Simple

Log::Log4perl

Log::Dispatch

Log::Dispatch::FileRotate

Locale::Maketext

Lingua::Stem

HTML::Entities

Getopt::Long

File::MMagic

Exception::Class

Email::Valid

Digest::MD5

Devel::StackTrace

DateTime

DateTime::Format::Strptime

Class::Singleton

Class::Observable

Class::Factory

Carp::Assert

CGI::Cookie

Cache::FileCache

Archive::Zip

Apache::Session

Algorithm::Dependency

OpenInteract

Config::DBI

DBIx::DataModel

DBIx::SQLEngine

AnyData

ResourcePool::Resource::Alzabo

Class::AlzaboWrapper

AppConfig

Params::Validate

DBIx::AnyDBD

Tie::IxHash

SQL::Abstract

PApp::SQL

Text::Autoformat

Term::Interact

IO::Extended

Class::Maker

XML::SAX

XML::SAX::Expat

XML::SAX::ExpatXS

DBIx::Romani

POSIX::strptime

Template::Plugin::ListUtil

Params::Util

List::Util

Data::OptList

Sub::Install

Net::FTP

HTML::Parser

Log::Agent

Cache

Storable

IO::Handle::Record

IO::File::Lockable

IO::File::CompressOnClose

IO::Tokenized

File::Type

File::BLOB

IO::File::Multi

IO::File::String

IO::File::Cached

IO::Compress::Base

IO::Compress::Base::Common

Compress::Zlib

IO::Uncompress::Gunzip

IO::Compress::Bzip2

Compress::Raw::Zlib

Compress::Raw::Bzip2

Test::Harness

Test::Builder

Sub::Uplevel

File::Basename::Object

MIME::Base64

Time::Local

Math::BigInt

GD

GD::Text

XSLoader

Module::Build

Bundle::DBD::CSV

Filter::Util::Call

RPC::PlServer

File::Find::Object

File::Find::Wanted

File::Finder

File::Find::Closures

Sub::Exporter

Test::Exception

Test::Assertions

Test::Assertions::TestScript

Log::Trace

UNIVERSAL::isa

DBD::Chart

DBIx::Chart

SQL::String

SQL::Shell

SQL::Loader

SQL::ReservedWords

SQL::SqlObject

SQL::Abstract::Limit

SQL::Library

SQL::Interpolate

SQL::Tidy

SQL::Translator::Producer::DBIx::Class::File::Simple

SQL::OrderBy

SQL::Tokenizer

SQL::Translator

SQL::Statement

SQL::KeywordSearch

SQL::YASP

DBIx::OO

SQL::AnchoredWildcards

SQL::Snippet

SQL::QueryBuilder::Simple

SQL::AnyDBD

SQL::Catalog

SQL::Schema

Error

Test::Simple

File::NCopy

Email::Send

DBD::mysql

Class::Driver

Pod::Parser

DBIx::Transaction

Module::Build::Compat

DBIx::Migration::Directories

DBD::SQLite2

SQLite::DB

Text::NeatTemplate

Text::ParseWords

Getopt::ArgvFile

SQLite::Work

Archive::Tar

IO::Zlib

CPAN::DistnameInfo

File::HomeDir

DBIx::SQLite::Simple

CPAN::SQLite

CGI::Session::SQLite

Class::DBI::SQLite

Tangram

Class::Tables

Database::Wrapper

Biblio::Thesaurus::SQLite


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

1;
